@@ -8,6 +8,7 @@ use base Games::Maze::SVG;
 use Carp;
 use Games::Maze;
 use strict;
+use warnings;
 
 =head1 NAME
 
@@ -15,11 +16,11 @@ Games::Maze::SVG::Rect - Build rectangular mazes in SVG.
 
 =head1 VERSION
 
-Version 0.71
+Version 0.72
 
 =cut
 
-our $VERSION = 0.71;
+our $VERSION = 0.72;
 
 =head1 SYNOPSIS
 
@@ -127,7 +128,7 @@ sub  new
     $obj->{dx} = DELTA_X;
     $obj->{dy} = DELTA_Y;
 
-    bless $obj;
+    return bless $obj, $class;
 }
 
 
@@ -139,7 +140,7 @@ Method always returns false.
 
 sub  is_hex
 {
-    undef;
+    return;
 }
 
 
@@ -151,7 +152,7 @@ Method always returns false.
 
 sub  is_hex_shaped
 {
-    undef;
+    return;
 }
 
 
@@ -185,7 +186,7 @@ sub  set_wall_form
         my $forms = join( ", ", sort keys %Walls );
         croak "\n'$form' is not a valid wall form.\nTry one of: $forms\n\n";
     }
-    $self;
+    return $self;
 }
 
 
@@ -215,7 +216,7 @@ sub  transform_grid
     my $walls = shift;
     my @out  = ();
 
-    my $sp = 'bevel' eq ($walls||'') ? '.' : ' ';
+    my $sp = 'bevel' eq ($walls||q{}) ? q{.} : q{ };
     remove_horiz_padding( $rows );
 
     # transform the printout into block commands
@@ -225,7 +226,7 @@ sub  transform_grid
     {
 	for(my $c=0; $c < $width; ++$c)
 	{
-	    if($rows->[$r]->[$c] eq ' ')
+	    if($rows->[$r]->[$c] eq q{ })
 	    {
         	$out[$r]->[$c] = 0;
 	    }
@@ -243,7 +244,8 @@ sub  transform_grid
 	    }
 	}
     }
-    @{$rows} = @out;
+
+    return @{$rows} = @out;
 }
 
 
@@ -263,25 +265,27 @@ Reference to an array of rows
 =cut
 
 sub  remove_horiz_padding
- {
-  my $rows = shift;
+{
+    my $rows = shift;
 
-  for(my $i = $#{$rows->[0]}; $i > 0; $i -= 3)
-   {
-    splice( @{$_}, $i-1, 1 ) foreach(@{$rows});
-   }
+    for(my $i = $#{$rows->[0]}; $i > 0; $i -= 3)
+    {
+        splice( @{$_}, $i-1, 1 ) foreach(@{$rows});
+    }
 
   # apparently trailing spaces that I wasn't aware of.
-  foreach my $r (@{$rows})
-   {
-    pop @{$r} if $r->[-1] eq ' ';
-   }
- }
+    foreach my $r (@{$rows})
+    {
+        pop @{$r} if $r->[-1] eq q{ };
+    }
+
+    return;
+}
 
 
 =item wall_definitions
 
-Method that returns the definition for the shaps used to build the walls.
+Method that returns the definition for the shapes used to build the walls.
 
 =cut
 
@@ -289,7 +293,7 @@ sub wall_definitions
 {
     my $self = shift;
 
-    $Walls{$self->{wallform}}
+    return $Walls{$self->{wallform}}
 }
 
 # _get_wall_forms
@@ -306,7 +310,7 @@ sub _get_wall_forms
     $/ = "\n";
     chomp( @list );
 
-    @list;
+    return @list;
 }
 
 
@@ -335,7 +339,7 @@ sub convert_start_position
     $x = 2*($x-1)+1;
     $y = 2*($y-1);
 
-    ($x, $y);
+    return ($x, $y);
 }
 
 =item convert_end_position
@@ -363,7 +367,7 @@ sub convert_end_position
     $x = 2*($x-1)+1;
     $y = 2*($y-1)+2;
 
-    ($x, $y);
+    return ($x, $y);
 }
 
 =item convert_sign_position
@@ -403,7 +407,7 @@ sub convert_sign_position
         $y -= $self->dy();
     }
 
-    ($x, $y);
+    return ($x, $y);
 }
 
 =back
@@ -415,7 +419,7 @@ G. Wade Johnson, C<< <wade@anomaly.org> >>
 =head1 BUGS
 
 Please report any bugs or feature requests to
-C<bug-maze-svg1@rt.cpan.org>, or through the web interface at
+C<bug-game-maze-svg@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Game-Maze-SVG>.
 I will be notified, and then you'll automatically be notified of progress on
 your bug as I make changes.
@@ -427,7 +431,7 @@ mazes.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2004-2005 G. Wade Johnson, all rights reserved.
+Copyright 2004-2006 G. Wade Johnson, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
